/v1/vpcs — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »

# /v1/vpcs

Contents

- /v1/vpcs
  - POST /v1/vpcs
    - Response status codes
    - Input
    - Output

## POST /v1/vpcs

Create a new VPCS instance

### Response status codes

- 400: Invalid project UUID
- 201: Instance created
- 409: Conflict

### Input

Name | Mandatory | Type | Description
--- | --- | --- | ---
console |  | ['integer', 'null'] | console TCP port
name | ✔ | string | VPCS device name
project_id | ✔ | string | Project UUID
startup_script |  | ['string', 'null'] | Content of the VPCS startup script
uuid |  | string | VPCS device UUID
vpcs_id |  | integer | VPCS device instance ID (for project created before GNS3 1.3)

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
console | ✔ | integer | console TCP port
name | ✔ | string | VPCS device name
project_id | ✔ | string | Project UUID
script_file |  | ['string', 'null'] | VPCS startup script
startup_script |  | ['string', 'null'] | Content of the VPCS startup script
uuid | ✔ | string | VPCS device UUID

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »